@@ -11,6 +11,8 @@ import java.io.FileDescriptor;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.util.Collection;
+import jnr.constants.platform.Confstr;
+import jnr.constants.platform.Pathconf;
 
 final class CheckedPOSIX implements POSIX {
     private final POSIX posix;
@@ -253,6 +255,10 @@ final class CheckedPOSIX implements POSIX {
         try { return posix.signal(sig, handler); } catch (UnsatisfiedLinkError ule) { return unimplementedNull(); }
     }
 
+    public int raise(int sig) {
+        try { return posix.raise(sig); } catch (UnsatisfiedLinkError ule) { return unimplementedInt(); }
+    }
+
     public int lchmod(String filename, int mode) {
         try { return posix.lchmod(filename, mode); } catch (UnsatisfiedLinkError ule) { return unimplementedInt(); }
     }
@@ -438,6 +444,14 @@ final class CheckedPOSIX implements POSIX {
         try { return posix.sysconf(name); } catch (UnsatisfiedLinkError ule) { return unimplementedInt(); }
     }
 
+    public int confstr(Confstr name, ByteBuffer buf, int len) {
+        try { return posix.confstr(name, buf, len); } catch (UnsatisfiedLinkError ule) { return unimplementedInt(); }
+    }
+
+    public int fpathconf(int fd, Pathconf name) {
+        try { return posix.fpathconf(fd, name); } catch (UnsatisfiedLinkError ule) { return unimplementedInt(); }
+    }
+
     public Times times() {
         try { return posix.times(); } catch (UnsatisfiedLinkError ule) { return unimplementedNull(); }
     }
@@ -462,6 +476,11 @@ final class CheckedPOSIX implements POSIX {
         try { return posix.fcntl(fd, fcntlConst); } catch (UnsatisfiedLinkError ule) { return unimplementedInt(); }
     }
 
+    public int fcntl(int fd, Fcntl fcntlConst, int arg) {
+        try { return posix.fcntl(fd, fcntlConst, arg); } catch (UnsatisfiedLinkError ule) { return unimplementedInt(); }
+    }
+
+    @Deprecated
     public int fcntl(int fd, Fcntl fcntlConst, int... arg) {
         try { return posix.fcntl(fd, fcntlConst); } catch (UnsatisfiedLinkError ule) { return unimplementedInt(); }
     }
@@ -618,4 +637,8 @@ final class CheckedPOSIX implements POSIX {
     public int gettimeofday(Timeval tv) {
         try {return posix.gettimeofday(tv); } catch (UnsatisfiedLinkError ule) { return unimplementedInt(); }
     }
+
+    public String gethostname() {
+        try {return posix.gethostname(); } catch (UnsatisfiedLinkError ule) { return unimplementedNull(); }
+    }
 }
